import { Construct } from 'constructs';
import { RemovalPolicy } from 'aws-cdk-lib';
import * as lambda from 'aws-cdk-lib/aws-lambda';
import * as s3 from 'aws-cdk-lib/aws-s3';
/**
 * (experimental) Properties to initialize an instance of `MicroAppsAppNextjsDemo`.
 *
 * @experimental
 */
export interface MicroAppsAppNextjsDemoProps {
    /**
     * (experimental) Name for the Lambda function.
     *
     * While this can be random, it's much easier to make it deterministic
     * so it can be computed for passing to `microapps-publish`.
     *
     * @default auto-generated
     * @experimental
     */
    readonly functionName?: string;
    /**
     * (experimental) Bucket with the static assets of the app.
     *
     * Next.js apps need access to the static assets bucket.
     *
     * @experimental
     */
    readonly staticAssetsS3Bucket: s3.IBucket;
    /**
     * (experimental) Removal Policy to pass to assets (e.g. Lambda function).
     *
     * @experimental
     */
    readonly removalPolicy?: RemovalPolicy;
    /**
     * (experimental) `sharp` node module Lambda Layer for Next.js image adjustments.
     *
     * @experimental
     * @example
     *
     * https://github.com/zoellner/sharp-heic-lambda-layer/pull/3
     */
    readonly sharpLayer?: lambda.ILayerVersion;
    /**
     * (experimental) NODE_ENV to set on Lambda.
     *
     * @experimental
     */
    readonly nodeEnv?: 'dev' | 'qa' | 'prod';
}
/**
 * (experimental) Represents a NextJS Demo app.
 *
 * @experimental
 */
export interface IMicroAppsAppNextjsDemo {
    /**
     * (experimental) The Lambda function created.
     *
     * @experimental
     */
    readonly lambdaFunction: lambda.IFunction;
}
/**
 * (experimental) NextJS Demo app for MicroApps framework.
 *
 * @see {@link https://nextjs.org/learn/basics/create-nextjs-app | Create NextJS App }
 * @experimental
 * @remarks Implemented from the NextJS tutorial.
 */
export declare class MicroAppsAppNextjsDemo extends Construct implements IMicroAppsAppNextjsDemo {
    private _lambdaFunction;
    /**
     * (experimental) The Lambda function created.
     *
     * @experimental
     */
    get lambdaFunction(): lambda.IFunction;
    /**
     * (experimental) Lambda function, permissions, and assets used by the MicroApps Release app.
     *
     * @experimental
     */
    constructor(scope: Construct, id: string, props: MicroAppsAppNextjsDemoProps);
}
